#ifndef __EPGSEARCHEXT_H
#define __EPGSEARCHEXT_H

#include <vdr/menu.h>
#include <vdr/menuitems.h>
#include <vdr/status.h>
#include <vdr/plugin.h>
#include <vdr/interface.h>
#include <vdr/skins.h>

#define MAXOSDTEXTWIDTH 45
#define ERROR(T) Skins.Message(mtError, T)
#define INFO(I)  Skins.Message(mtInfo, I)


class cSearchExt : public cListObject {
  friend class cMenuEditSearchExt;
public:
  char     search[MaxFileName];
  int      options;
  int      useTime;
  int      startTime;
  int      stopTime;
  int      useChannel;
  int      useCase;
  int      mode;
  int      useTitle;
  int      useSubtitle;
  int      useDescription;
  cChannel *channel;

  static char *buffer;
public:
  cSearchExt(void);
  virtual ~cSearchExt(void);
  cSearchExt& operator= (const cSearchExt &SearchExt);
  virtual bool operator< (const cListObject &ListObject);

  const char *Search(void) { return search; }
  int Options(void) { return options; }
  int StartTime(void) { return startTime; }
  int StopTime(void) { return stopTime; }
  int UseChannel(void) { return useChannel; }
  cChannel *Channel(void) { return channel; }

  const char *ToText(void);
  bool Parse(const char *s);
  bool Save(FILE *f);
  };

class cSearchExts : public cConfig<cSearchExt> {
private:
public:
  cSearchExts(void);
  };

extern cSearchExts SearchExts;

// --- cMenuEditSearchExt --------------------------------------------------------

class cMenuEditSearchExt : public cOsdMenu {
private:
  cSearchExt *searchExt;
  cSearchExt data;
  int channel;
  int useTime;
  bool addIfConfirmed;
public:
  cMenuEditSearchExt(cSearchExt *SearchExt, bool New = false);
  virtual ~cMenuEditSearchExt();
  void Set();
  virtual eOSState ProcessKey(eKeys Key);
  };

class cMenuEPGSearchExt : public cOsdMenu {
  private:
	eOSState New(void);
	eOSState Delete(void);
  protected:
    	virtual eOSState ProcessKey(eKeys Key);
  public:
    	cMenuEPGSearchExt(void);
	cSearchExt* CurrentSearchExt(void);
	eOSState Search(void);
  };

// --- cMenuWhatsOnSearchEPGItem ------------------------------------------------------
class cMenuWhatsOnSearchEPGItem : public cOsdItem {
public:
  const cEvent *eventInfo;
  cMenuWhatsOnSearchEPGItem(const cEvent *EventInfo);
};

class cMenuWhatsOnSearchEPG : public cOsdMenu {
private:
  cSearchExt* searchExt;
  bool BuildList(void);
  cEvent *GetEventByTitle(const cSchedule* schedules, const char *p2, const cEvent *Start=NULL);
  cEvent * GetEventBySearchExt(const cSchedule *schedules, cSearchExt* SearchExt, const cEvent *Start);
  virtual eOSState ProcessKey(eKeys Key);
  eOSState Summary(void);
  eOSState Record(void);
  void SetHelpKeys(void);
  eOSState Switch(void);

  static const cEvent *scheduleEventInfo;
  static int currentChannel;
public:
  char *m_pSearchString;
  bool m_bSort;
public:
  cMenuWhatsOnSearchEPG(const char *p2);
  cMenuWhatsOnSearchEPG(cSearchExt*);
  ~cMenuWhatsOnSearchEPG() {free(m_pSearchString);}
  };

// --- cMenuEditTimer --------------------------------------------------------

class cMenuEditTimer : public cOsdMenu {
private:
  cTimer *timer;
  cTimer data;
  int channel;
  bool addIfConfirmed;
  cMenuEditDateItem *firstday;
  void SetFirstDayItem(void);
public:
  cMenuEditTimer(cTimer *Timer, bool New = false);
  virtual ~cMenuEditTimer();
  virtual eOSState ProcessKey(eKeys Key);
  };

#endif
